diff --git a/DI/XDIHelperExtension.cs b/DI/XDIHelperExtension.cs
index 627befe..c486407 100644
--- a/DI/XDIHelperExtension.cs
+++ b/DI/XDIHelperExtension.cs
@@ -14,7 +14,7 @@ namespace xWebinarService.DI
public static class XDIHelperExtension
{
///
- /// Register Module Provided Service on DI
+ /// Register Service ...
///
///
///
@@ -33,7 +33,7 @@ namespace xWebinarService.DI
//
#region Private ...
///
- /// a LogTag for XWebinarService ...
+ /// a LogTag for Service ...
///
private static string XLogTag = "XWebinarService";
@@ -47,7 +47,7 @@ namespace xWebinarService.DI
}
///
- /// Register Push Service ...
+ /// Register Service ...
///
///
///
@@ -80,16 +80,26 @@ namespace xWebinarService.DI
}
//
- // Check String Repository Exists ...
- var isWebinarRepositoryExists = !services
- .GetRegisteredService()
- .IsNull() &&
- !services.GetRegisteredService()
+ // Check Dependencies Exists ...
+ var isDependenciesPassed = !services
+ .GetRegisteredService()
.IsNull();
- if (!isWebinarRepositoryExists)
+ if (!isDependenciesPassed)
{
//
- Log("AddWebinarService failed, IXWebinarRepository or IXWebinarSubscriberRepository not provided ...");
+ Log("AddFileService failed due Dependencies Issues, IXWebinarSubscriberRepository not provided ...");
+ throw exception;
+ }
+
+ //
+ // Check Repository Exists ...
+ var isRepositoryExists = !services
+ .GetRegisteredService()
+ .IsNull();
+ if (!isRepositoryExists)
+ {
+ //
+ Log("AddWebinarService failed, IXWebinarRepository not provided ...");
throw exception;
}
@@ -111,6 +121,5 @@ namespace xWebinarService.DI
Log("AddWebinarService Succeed ...");
}
#endregion
-
}
}
\ No newline at end of file